DICTBELT
========

The bat-belt for dictionaries!

This library contains a set of functions and wrapper to better deal with complex
hierarchies of dictionaries (and lists).

Of note is the `dic_walk()` function that allows traversing an entire `dict` and
`list` tree.

